* Description: This do-file creates the data_base built.dta to work with from SOEP v.33

*STRUCTURE:
* STEP A: Collect variables from various SOEP datasets and label
* STEP B: Merge into unique dataset
* STEP C: Prepare variables 

clear all
set more off

global path "/Users/marcocerundolo/Dropbox/populism/SOEP/replication"
global data "$path/data"

cap cd "$data"

********************************************************************************
* STEP A: Collect variables from various SOEP datasets and label
********************************************************************************

*** PEQUIV *********************************************************************

use "$data/input/pequiv.dta", clear

keep cid hid pid syear i11102 x11105 d11101 
sort cid hid pid syear 
save "$data/temp/pequiv_mod.dta", replace

*** PGEN ***********************************************************************

use "$data/input/pgen.dta", clear				

* generate labor force status
label define pgemplst_label -2 "Doesn't Apply" -1 "Not Specified" 1 "Full-Time Employment" ///
							 2 "Regular Part-Time" 3 "Vocational Training" 4 "Marginal, Irregular Part-Time Employment" ///
							 5 "Not Employed" 6 "Sheltered workshop"
label values pgemplst pgemplst_label

keep cid pid hid syear pgemplst pglfs pgisced97
sort cid hid pid syear
save "$data/temp/pgen_mod.dta", replace

*** PL *************************************************************************

use "$data/input/pl.dta", clear

* economic satisfaction
gen	  income_sat = plh0175
replace	income_sat = . if income_sat < 0

* relabel party preference
label var plh0012 "Party Preference"
label define plh0012 -5 "Not Contained" -2 "Doesn't Apply" -1 "Not Specified", modify
label values plh0012 plh0012

* relabel Personal Willingness to Take Risk
label var plh0204 "Personal Willingness to Take Risk"
label define plh0204_label -8 "Not Contained" -5 "Not Contained" -2 "Doesn't Apply" -1 "Not Specified" 0 "Very Risk-Av." 10 "Very Risk-Lov."
label values plh0204 plh0204_label

sort cid hid pid syear
keep cid hid pid syear plh0012 plh0204 income_sat
	 
save "$data/temp/pl_mod.dta", replace

*** PPFADL *********************************************************************

* generate current region (east/west)
use "$data/input/ppfadl.dta", clear
label define sampreg_label -2 "Doesn't apply" 1 "West Germany (incl. West Berlin)" 2 "East Germany (incl. East Berlin)" 
label values sampreg sampreg_label
replace sampreg=0 if sampreg==2
label define sampreg_label 0 "East Germany (incl. East Berlin)", modify
label var sampreg "Region of residence: East=0, West=1"
sort cid pid syear
keep cid pid syear sampreg
save "$data/temp/ppfadl_mod.dta", replace

*** PPFAD **********************************************************************

use "$data/input/ppfad.dta", clear
* label sex
tab sex
replace sex=0 if sex==2
label define sex_label 1 "Male" 0 "Female" 
label values sex sex_label
label var sex "Sex: 1=Male, 0=Female"
replace sex=. if sex<0

* label age
tab gebjahr
label var gebjahr "Year of birth"

* label migration status
tab migback
label define migback_label 1 "No Background" 2 "Direct Background" 3 "Indirect Background" 4 "Background not differentiable"
label values migback migback_label
label var migback "Migration Background"

keep cid pid sex migback gebjahr loc1989
sort cid pid
save "$data/temp/ppfad_mod.dta", replace

********************************************************************************
* STEP B: Merge into unique database
********************************************************************************

use "$data/temp/pequiv_mod", clear

merge cid hid pid syear using "$data/temp/pl_mod.dta"
gen unmerged1=0
replace unmerged1=1 if _merge!=3 										
drop _merge
sort cid hid pid syear

merge cid hid pid syear using "$data/temp/pgen_mod.dta"
gen unmerged2=0
replace unmerged2=1 if _merge!=3 										
drop _merge
sort cid pid

merge cid pid using "$data/temp/ppfad_mod.dta"
gen unmerged3=0
replace unmerged3=1 if _merge!=3 										
drop _merge
sort cid pid syear						

merge cid pid syear using "$data/temp/ppfadl_mod.dta"
gen unmerged4=0
replace unmerged4=1 if _merge!=3 										
drop _merge
sort cid hid pid syear

gen unmerged_tot = unmerged1+unmerged2+unmerged3+unmerged4
tab unmerged_tot
tab x11105 unmerged_tot
drop if x11105==0 
tab d11101 unmerged_tot	
drop if d11101<18 
tab unmerged_tot
drop if unmerged_tot!=0						
//Dropping those who were contacted but did not answer and those aged less than 18 leaves a match rate of 99.99%.	

********************************************************************************
* STEP C: Prepare variables 
********************************************************************************

*** Generate dummy for Populist in general *************************************

gen populist_dummy=0
replace populist_dummy=1 if plh0012==27 | plh0012==7 | plh0012==26
replace populist_dummy=. if plh0012==-5

*** Generate household income **************************************************

gen income_HH=i11102 if i11102>=0
gen ln_income_HH=ln(income_HH)

* trim extreme values in HH_PP income
qui sum income_HH, d
replace income_HH =. if !inrange(income_HH,`r(p1)', `r(p99)')				
qui sum ln_income_HH, d
replace ln_income_HH =. if !inrange(ln_income_HH,`r(p1)', `r(p99)')				

*** Generate delta incomes *****************************************************

*generate id for person-household pair, pid_hid. 
sort pid hid syear
by pid hid: gen pid_hid=1 if _n==1
replace pid_hid=sum(pid_hid)
replace pid_hid=. if pid==. | hid==.

* generate time in household
sort pid_hid syear
by pid_hid: gen time=_n
bysort pid_hid: egen n_obs=max(time)

* generate dummy for first observation of household ever
gen first_household_ever=0
sort pid hid syear
by pid hid: replace first_household_ever = _n == 1 

* generate dummy for last observation of household ever
gen last_household_ever=0
gsort +pid +hid -syear
by pid hid: replace last_household_ever = _n == 1 

* generate 3yy moving average of lags
sort pid hid syear
gen income_HH_MA3_lag=(income_HH[_n-3]+income_HH[_n-2]+income_HH[_n-1])/3 if n_obs>=4
replace income_HH_MA3_lag=. if first_household_ever==1 | first_household_ever[_n-1]==1 | first_household_ever[_n-2]==1

* generate variation of current w.r.t. 3yy MA lag
sort pid syear
gen delta_income_YoMA3=ln(income_HH)-ln(income_HH_MA3_lag)

sum delta_income_YoMA3,d
replace delta_income_YoMA3 =. if !inrange(delta_income_YoMA3,`r(p1)', `r(p99)')				 
label var delta_income_YoMA3 "YoMA3l variation in income"

* gen pct variations in income

gen pct_loss_YoMA3=min(0, delta_income_YoMA3)
sort pid syear
replace pct_loss_YoMA3=. if delta_income_YoMA3==.

cap drop if syear<=2007 //Keep observations only after 2007

*** Generate age class *********************************************************

gen age=syear-gebjahr  if gebjahr>=0

gen age_under_28=0 if age!=.
replace age_under_28=1 if age<28

gen age_over_45=0 if age!=.
replace age_over_45=1 if age>45

gen unemployed=0
replace unemployed=1 if pglfs==6 & pgemplst==5	
replace unemployed=. if pglfs<0	& pgemplst==5			
gen out_of_LF=0
replace out_of_LF=1 if pglfs!=6 & pgemplst==5
replace out_of_LF=. if pglfs<0 & pgemplst==5			 

*** Generate migration dummies *************************************************

gen migrant_direct=0
replace migrant_direct=1 if migback==2
replace migrant_direct=. if migback==-1

gen migrant_indirect=0
replace migrant_indirect=1 if migback==3
replace migrant_indirect=. if migback==-1

*** Generate control for East Germany ******************************************

gen east_germany_GS=0 
replace east_germany_GS=1 if loc1989==1	
replace east_germany_GS=1 if gebjahr>1989 & sampreg==0 & loc1989==-2 // for those born after 1989, east_germany_GS=1 if they are resident of east germany at the time the survey is answered.

*** Generate edu class (based on pequiv codebook) ******************************

gen edu_low=0
replace edu_low=1 if pgisced97==0 | pgisced97==1 | pgisced97==2 
replace edu_low=. if pgisced97==-1 | pgisced97==.

gen edu_medium=0
replace edu_medium=1 if pgisced97==3 | pgisced97==4 
replace edu_medium=. if pgisced97==-1 | pgisced97==.

gen edu_high=0
replace edu_high=1 if pgisced97==5 | pgisced97==6 
replace edu_high=. if pgisced97==-1 | pgisced97==.

*** Generate dummy for large income loss ***************************************

g loss3 = 0 
replace loss3 = 1 if pct_loss_YoMA3 < -0.26 // this corresponds to 80% percentiles of losses. 
replace loss3 =. if pct_loss_YoMA3 ==.

*** Generate income dissat and dummy for extreme income dissat *****************

g income_dissat7 = (income_sat < 4) if income_sat != .
g income_dissat = 10 - income_sat

*** Generate dummy for extreme risk love ***************************************

g risk9 = 0
replace risk9 = 1 if plh0204 >8
replace risk9=. if plh0204<0

********************************************************************************
* Clean and Save
********************************************************************************

* rename variables 

rename sex male 

rename plh0204 risk_love 
replace risk_love = . if risk_love < 0 

rename plh0012 party_pref

* keep only needed variables 

#delimit ;
keep pid hid syear populist_dummy party_pref risk_love east_germany_GS male migrant_direct
migrant_indirect edu_* ln_income_HH unemployed out_of_LF pct_loss_YoMA3 
age_under_28 age_over_45 loss3 income_dissat* risk9;
#delimit cr

* label variables

label var populist_dummy "Populist (dummy)"
label var risk_love "Risk Love"
label var risk9 "Extreme Risk Love"
label var out_of_LF "Out of Labor Force"
label var unemployed "Unemployed"
label var ln_income_HH "Income"
label var loss3 "Large Income Loss"
label var pct_loss_YoMA3 "Income Loss (YoMA3)"
label var age_under_28 "Age Under 28"
label var age_over_45 "Age Over 45"
label var male "Male"
label var migrant_direct "Direct Immigrant"
label var migrant_indirect "Second-Generation Immigrant"
label var edu_low "Low Education Level"
label var edu_medium "Medium Education Level"
label var edu_high "High Education Level"
label var east_germany_GS "Resident in East Germany"
label var income_dissat "Income Dissatisfaction"
label var income_dissat7 "Extreme Income Dissatisfaction"

sort hid pid syear
tsset pid syear

* save

save "$data/output/built.dta", replace
